summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--Makefile.am2
-rw-r--r--Makefile.bsd-wrapper36
-rw-r--r--config/GiveConsole2
-rw-r--r--config/Makefile.am34
-rw-r--r--config/README10
-rw-r--r--config/TakeConsole2
-rw-r--r--config/Xreset.cpp2
-rw-r--r--config/Xsession.cpp8
-rw-r--r--config/Xstartup.cpp2
-rw-r--r--config/xdm-config.cpp44
-rw-r--r--config/xenodm-config.cpp44
-rw-r--r--configure.ac108
-rw-r--r--greeter/Makefile.am2
-rw-r--r--man/Makefile.am16
-rw-r--r--man/xenodm.man (renamed from man/xdm.man)217
-rw-r--r--xenodm/Makefile.am (renamed from xdm/Makefile.am)10
-rw-r--r--xenodm/auth.c (renamed from xdm/auth.c)0
-rw-r--r--xenodm/dm.c (renamed from xdm/dm.c)6
-rw-r--r--xenodm/dpylist.c (renamed from xdm/dpylist.c)0
-rw-r--r--xenodm/error.c (renamed from xdm/error.c)0
-rw-r--r--xenodm/file.c (renamed from xdm/file.c)0
-rw-r--r--xenodm/mitauth.c (renamed from xdm/mitauth.c)0
-rw-r--r--xenodm/netaddr.c (renamed from xdm/netaddr.c)0
-rw-r--r--xenodm/reset.c (renamed from xdm/reset.c)0
-rw-r--r--xenodm/resource.c (renamed from xdm/resource.c)12
-rw-r--r--xenodm/server.c (renamed from xdm/server.c)0
-rw-r--r--xenodm/session.c (renamed from xdm/session.c)1
-rw-r--r--xenodm/util.c (renamed from xdm/util.c)0
28 files changed, 279 insertions, 279 deletions
diff --git a/Makefile.am b/Makefile.am
index 2f7be52..c1e1284 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -19,7 +19,7 @@
# TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
# PERFORMANCE OF THIS SOFTWARE.
-SUBDIRS = config greeter include man xdm
+SUBDIRS = config greeter include man xenodm
ACLOCAL_AMFLAGS = -I m4
diff --git a/Makefile.bsd-wrapper b/Makefile.bsd-wrapper
index 9fd4c29..88ce5a6 100644
--- a/Makefile.bsd-wrapper
+++ b/Makefile.bsd-wrapper
@@ -1,8 +1,8 @@
# $OpenBSD: Makefile.bsd-wrapper,v 1.22 2015/03/15 19:09:22 matthieu Exp $
.include <bsd.own.mk>
-XDMCONFIGDIR=/etc/X11/xdm
-PIXMAPDIR=$(XDMCONFIGDIR)/pixmaps
+XENODMCONFIGDIR=/etc/X11/xenodm
+PIXMAPDIR=$(XENODMCONFIGDIR)/pixmaps
.if ${MACHINE} == i386 || ${MACHINE} == amd64 || ${MACHINE} == macppc
DEFAULT_VT= --with-default-vt=vt05
@@ -15,8 +15,8 @@ CONFIGURE_ARGS= --enable-privsep \
--enable-bsdauth \
$(DEFAULT_VT) \
--disable-ipv6 \
- --with-authdir=$(XDMCONFIGDIR) \
- --with-xdmlibdir=$(XDMCONFIGDIR) \
+ --with-authdir=$(XENODMCONFIGDIR) \
+ --with-xenodmlibdir=$(XENODMCONFIGDIR) \
--with-pixmapdir=$(PIXMAPDIR) \
--with-bw-pixmap=OpenBSD_1bpp.xpm \
--with-color-pixmap=OpenBSD_15bpp.xpm
@@ -27,9 +27,9 @@ realinstall:
INSTALL_DATA=: \
INSTALL_SCRIPT=:
-XDMCONFIGFILES= \
- xdm-config Xresources Xservers Xaccess
-XDMCONFIGSCRIPTS= \
+XENODMCONFIGFILES= \
+ xenodm-config Xresources Xservers Xaccess
+XENODMCONFIGSCRIPTS= \
Xsession GiveConsole TakeConsole Xsetup_0 Xstartup Xreset Xwilling
afterinstall:
@@ -37,23 +37,23 @@ afterinstall:
$(INSTALL_DATA) ${.CURDIR}/config/OpenBSD_4bpp.xpm $(DESTDIR)$(PIXMAPDIR)
$(INSTALL_DATA) ${.CURDIR}/config/OpenBSD_8bpp.xpm $(DESTDIR)$(PIXMAPDIR)
$(INSTALL_DATA) ${.CURDIR}/config/OpenBSD_15bpp.xpm $(DESTDIR)$(PIXMAPDIR)
- cd man ; $(INSTALL_DATA) xdm.1 $(DESTDIR)$(MANDIR)1/
- @cd config ; for f in $(XDMCONFIGFILES); do \
- if ! test -f $(DESTDIR)$(XDMCONFIGDIR)/$$f ; then \
+ cd man ; $(INSTALL_DATA) xenodm.1 $(DESTDIR)$(MANDIR)1/
+ @cd config ; for f in $(XENODMCONFIGFILES); do \
+ if ! test -f $(DESTDIR)$(XENODMCONFIGDIR)/$$f ; then \
if test -f $$f; then d=; else d="$(.CURDIR)/config/"; fi; \
- echo "$(INSTALL_DATA) $$d$$f $(DESTDIR)$(XDMCONFIGDIR)"; \
- $(INSTALL_DATA) $$d$$f $(DESTDIR)$(XDMCONFIGDIR) ;\
+ echo "$(INSTALL_DATA) $$d$$f $(DESTDIR)$(XENODMCONFIGDIR)"; \
+ $(INSTALL_DATA) $$d$$f $(DESTDIR)$(XENODMCONFIGDIR) ;\
else \
- echo "not overwriting $(DESTDIR)$(XDMCONFIGDIR)/$$f" ;\
+ echo "not overwriting $(DESTDIR)$(XENODMCONFIGDIR)/$$f" ;\
fi \
done
- @cd config ; for f in $(XDMCONFIGSCRIPTS); do \
- if ! test -f $(DESTDIR)$(XDMCONFIGDIR)/$$f ; then \
+ @cd config ; for f in $(XENODMCONFIGSCRIPTS); do \
+ if ! test -f $(DESTDIR)$(XENODMCONFIGDIR)/$$f ; then \
if test -f $$f; then d=; else d="$(.CURDIR)/config/"; fi; \
- echo "$(INSTALL) $$f $(DESTDIR)$(XDMCONFIGDIR)"; \
- $(INSTALL) $$d$$f $(DESTDIR)$(XDMCONFIGDIR) ;\
+ echo "$(INSTALL) $$f $(DESTDIR)$(XENODMCONFIGDIR)"; \
+ $(INSTALL) $$d$$f $(DESTDIR)$(XENODMCONFIGDIR) ;\
else \
- echo "not overwriting $(DESTDIR)$(XDMCONFIGDIR)/$$f" ;\
+ echo "not overwriting $(DESTDIR)$(XENODMCONFIGDIR)/$$f" ;\
fi \
done
diff --git a/config/GiveConsole b/config/GiveConsole
index cc07003..b209f17 100644
--- a/config/GiveConsole
+++ b/config/GiveConsole
@@ -11,4 +11,4 @@ chown $USER /dev/console
if [ -c /dev/drm0 ]; then
chown $USER /dev/drm0
fi
-/usr/X11R6/bin/sessreg -a -l $DISPLAY -u none -x /etc/X11/xdm/Xservers $USER
+/usr/X11R6/bin/sessreg -a -l $DISPLAY -u none -x /etc/X11/xenodm/Xservers $USER
diff --git a/config/Makefile.am b/config/Makefile.am
index 30e22ea..37bfb3b 100644
--- a/config/Makefile.am
+++ b/config/Makefile.am
@@ -2,38 +2,38 @@
include $(top_srcdir)/cpprules.in
-xdmscriptdir = $(XDMSCRIPTDIR)
-xdmconfigdir = $(XDMCONFIGDIR)
+xenodmscriptdir = $(XENODMSCRIPTDIR)
+xenodmconfigdir = $(XENODMCONFIGDIR)
-dist_xdmconfig_DATA = \
+dist_xenodmconfig_DATA = \
Xaccess
-xdmconfig_DATA = \
- xdm-config \
+xenodmconfig_DATA = \
+ xenodm-config \
Xresources \
Xservers
-xdmscript_SCRIPTS = \
+xenodmscript_SCRIPTS = \
Xreset \
Xsession \
Xstartup
-dist_xdmscript_SCRIPTS = \
+dist_xenodmscript_SCRIPTS = \
GiveConsole \
TakeConsole \
Xsetup_0 \
Xwilling
-pixmapdir = $(XDM_PIXMAPDIR)
+pixmapdir = $(XENODM_PIXMAPDIR)
dist_pixmap_DATA = xorg-bw.xpm xorg.xpm
-BUILT_SOURCES = Xservers.ws xdm-config Xreset Xresources Xsession Xstartup
+BUILT_SOURCES = Xservers.ws xenodm-config Xreset Xresources Xsession Xstartup
CLEANFILES = $(BUILT_SOURCES) Xservers
EXTRA_DIST = Xservers.ws.cpp Xservers.fs \
- xdm-config.cpp Xreset.cpp Xresources.cpp Xsession.cpp Xstartup.cpp
+ xenodm-config.cpp Xreset.cpp Xresources.cpp Xsession.cpp Xstartup.cpp
Xservers: Xservers.$(SERVERSTYPE)
ln -s Xservers.$(SERVERSTYPE) Xservers
@@ -41,8 +41,8 @@ Xservers: Xservers.$(SERVERSTYPE)
# Defines used when cpp'ing config files to replace settings in the files
#if USE_XPM
-XPMDEFINES = -DXPM -DBITMAPDIR=$(XDM_PIXMAPDIR) -DXDM_PIXMAP=$(XDM_PIXMAP) \
- -DXDM_BWPIXMAP=$(XDM_BWPIXMAP)
+XPMDEFINES = -DXPM -DBITMAPDIR=$(XENODM_PIXMAPDIR) -DXENODM_PIXMAP=$(XENODM_PIXMAP) \
+ -DXENODM_BWPIXMAP=$(XENODM_BWPIXMAP)
#endif
#if HAVE_MKTEMP_COMMAND
@@ -51,11 +51,11 @@ MKTEMP_DEFINES = -DMKTEMP_COMMAND=$(MKTEMP_COMMAND)
CPP_FILES_FLAGS = -DBINDIR="$(bindir)" -DDEFAULTVT="$(DEFAULTVT)" \
-DUTMP_FILE="$(UTMP_FILE)" -DWTMP_FILE="$(WTMP_FILE)" \
- -DXDMDIR="$(XDMLIBDIR)" -DXDMLOGDIR="$(XDMLOGDIR)" \
- -DXDMXAUTHDIR="$(XDMXAUTHDIR)" \
- -DXDMPIDDIR="$(XDMPIDDIR)" -DXDMCONFIGDIR="$(XDMCONFIGDIR)" \
- -DXDMSCRIPTDIR="$(XDMSCRIPTDIR)" -DSU="$(SU)" \
- -DCHOOSERPATH="$(XDMLIBDIR)/chooser" $(XPMDEFINES) \
+ -DXENODMDIR="$(XENODMLIBDIR)" -DXENODMLOGDIR="$(XENODMLOGDIR)" \
+ -DXENODMXAUTHDIR="$(XENODMXAUTHDIR)" \
+ -DXENODMPIDDIR="$(XENODMPIDDIR)" -DXENODMCONFIGDIR="$(XENODMCONFIGDIR)" \
+ -DXENODMSCRIPTDIR="$(XENODMSCRIPTDIR)" -DSU="$(SU)" \
+ -DCHOOSERPATH="$(XENODMLIBDIR)/chooser" $(XPMDEFINES) \
-DSHELL_CMD="$(SHELL_CMD)" $(MKTEMP_DEFINES)
Xservers.ws: $(srcdir)/Xservers.ws.cpp
diff --git a/config/README b/config/README
index 04922e5..36a2313 100644
--- a/config/README
+++ b/config/README
@@ -1,10 +1,10 @@
-Xdm Sample Configuration
+Xenodm Sample Configuration
This directory contains a collection of files which describe a sample
-configuration of xdm. Choose between the sample Xservers.* files; copy the
-appropriate one to "$(XDMDIR)/Xservers" along with the other
+configuration of xenodm. Choose between the sample Xservers.* files; copy the
+appropriate one to "$(XENODMDIR)/Xservers" along with the other
files in this directory.
-Only a few of the many configuration parameters which xdm can be tuned with
-are set in this sample, read the xdm manual page for a complete description.
+Only a few of the many configuration parameters which xenodm can be tuned with
+are set in this sample, read the xenodm manual page for a complete description.
diff --git a/config/TakeConsole b/config/TakeConsole
index 2581b4c..7b08050 100644
--- a/config/TakeConsole
+++ b/config/TakeConsole
@@ -8,4 +8,4 @@ chown root /dev/console
if [ -c /dev/drm0 ]; then
chown root /dev/drm0
fi
-/usr/X11R6/bin/sessreg -d -l $DISPLAY -u /var/run/utmp -x /etc/X11/xdm/Xservers $USER
+/usr/X11R6/bin/sessreg -d -l $DISPLAY -u /var/run/utmp -x /etc/X11/xenodm/Xservers $USER
diff --git a/config/Xreset.cpp b/config/Xreset.cpp
index 321cd89..e890814 100644
--- a/config/Xreset.cpp
+++ b/config/Xreset.cpp
@@ -2,4 +2,4 @@ XCOMM!/bin/sh
XCOMM Deregister a login. (Derived from TakeConsole as follows:)
XCOMM
BINDIR/sessreg -d -w WTMP_FILE -u UTMP_FILE \
- -x XDMCONFIGDIR/Xservers -l $DISPLAY -h "" $USER
+ -x XENODMCONFIGDIR/Xservers -l $DISPLAY -h "" $USER
diff --git a/config/Xsession.cpp b/config/Xsession.cpp
index 4bac5e3..05bc1f5 100644
--- a/config/Xsession.cpp
+++ b/config/Xsession.cpp
@@ -92,13 +92,13 @@ else
. /etc/default/xdesktops
}
- [ -r /etc/default/xdm ] && {
- . /etc/default/xdm
+ [ -r /etc/default/xenodm ] && {
+ . /etc/default/xenodm
}
XCOMM Allow the user to over-ride the system default desktop
- [ -r $HOME/.xdmdesktop ] && {
- . $HOME/.xdmdesktop
+ [ -r $HOME/.xenodmdesktop ] && {
+ . $HOME/.xenodmdesktop
}
[ -n "$XDESKTOP" ] && {
diff --git a/config/Xstartup.cpp b/config/Xstartup.cpp
index 1bc8dcc..dd9bfe4 100644
--- a/config/Xstartup.cpp
+++ b/config/Xstartup.cpp
@@ -7,4 +7,4 @@ if [ -f /etc/nologin ]; then
exit 1
fi
exec BINDIR/sessreg -a -w WTMP_FILE -u UTMP_FILE \
- -x XDMCONFIGDIR/Xservers -l $DISPLAY -h "" $USER
+ -x XENODMCONFIGDIR/Xservers -l $DISPLAY -h "" $USER
diff --git a/config/xdm-config.cpp b/config/xdm-config.cpp
deleted file mode 100644
index 24702a3..0000000
--- a/config/xdm-config.cpp
+++ /dev/null
@@ -1,44 +0,0 @@
-! $OpenBSD: xdm-config.cpp,v 1.5 2012/10/07 15:55:28 matthieu Exp $
-!
-!
-!
-!
-!
-#ifndef XDMCONFIGDIR
-#define XDMCONFIGDIR XDMDIR
-#endif
-#ifndef XDMSCRIPTDIR
-#define XDMSCRIPTDIR XDMDIR
-#endif
-DisplayManager.authDir: XDMXAUTHDIR
-DisplayManager.errorLogFile: XDMLOGDIR/xdm.log
-DisplayManager.pidFile: XDMPIDDIR/xdm.pid
-DisplayManager.keyFile: XDMCONFIGDIR/xdm-keys
-DisplayManager.servers: XDMCONFIGDIR/Xservers
-DisplayManager.accessFile: XDMCONFIGDIR/Xaccess
-DisplayManager*resources: XDMCONFIGDIR/Xresources
-DisplayManager.willing: SU nobody -s /bin/sh XDMSCRIPTDIR/Xwilling
-! All displays should use authorization, but we cannot be sure
-! X terminals may not be configured that way, so they will require
-! individual resource settings.
-DisplayManager*authorize: true
-!
-DisplayManager*chooser: CHOOSERPATH
-DisplayManager*startup: XDMSCRIPTDIR/Xstartup
-DisplayManager*session: XDMSCRIPTDIR/Xsession
-DisplayManager*reset: XDMSCRIPTDIR/Xreset
-DisplayManager*authComplain: true
-! The following three resources set up display :0 as the console.
-DisplayManager._0.setup: XDMSCRIPTDIR/Xsetup_0
-DisplayManager._0.startup: XDMSCRIPTDIR/GiveConsole
-DisplayManager._0.reset: XDMSCRIPTDIR/TakeConsole
-#if HAS_DES_AUTH == YES
-DisplayManager.*.authName: MIT-MAGIC-COOKIE-1
-#endif
-#ifdef XPM
-DisplayManager*loginmoveInterval: 10
-#endif /* XPM */
-!
-! SECURITY: do not listen for XDMCP or Chooser requests
-! Comment out this line if you want to manage X terminals with xdm
-DisplayManager.requestPort: 0
diff --git a/config/xenodm-config.cpp b/config/xenodm-config.cpp
new file mode 100644
index 0000000..ab82e64
--- /dev/null
+++ b/config/xenodm-config.cpp
@@ -0,0 +1,44 @@
+! $OpenBSD: xenodm-config.cpp,v 1.5 2012/10/07 15:55:28 matthieu Exp $
+!
+!
+!
+!
+!
+#ifndef XENODMCONFIGDIR
+#define XENODMCONFIGDIR XENODMDIR
+#endif
+#ifndef XENODMSCRIPTDIR
+#define XENODMSCRIPTDIR XENODMDIR
+#endif
+DisplayManager.authDir: XENODMXAUTHDIR
+DisplayManager.errorLogFile: XENODMLOGDIR/xenodm.log
+DisplayManager.pidFile: XENODMPIDDIR/xenodm.pid
+DisplayManager.keyFile: XENODMCONFIGDIR/xenodm-keys
+DisplayManager.servers: XENODMCONFIGDIR/Xservers
+DisplayManager.accessFile: XENODMCONFIGDIR/Xaccess
+DisplayManager*resources: XENODMCONFIGDIR/Xresources
+DisplayManager.willing: SU nobody -s /bin/sh XENODMSCRIPTDIR/Xwilling
+! All displays should use authorization, but we cannot be sure
+! X terminals may not be configured that way, so they will require
+! individual resource settings.
+DisplayManager*authorize: true
+!
+DisplayManager*chooser: CHOOSERPATH
+DisplayManager*startup: XENODMSCRIPTDIR/Xstartup
+DisplayManager*session: XENODMSCRIPTDIR/Xsession
+DisplayManager*reset: XENODMSCRIPTDIR/Xreset
+DisplayManager*authComplain: true
+! The following three resources set up display :0 as the console.
+DisplayManager._0.setup: XENODMSCRIPTDIR/Xsetup_0
+DisplayManager._0.startup: XENODMSCRIPTDIR/GiveConsole
+DisplayManager._0.reset: XENODMSCRIPTDIR/TakeConsole
+#if HAS_DES_AUTH == YES
+DisplayManager.*.authName: MIT-MAGIC-COOKIE-1
+#endif
+#ifdef XPM
+DisplayManager*loginmoveInterval: 10
+#endif /* XPM */
+!
+! SECURITY: do not listen for XDMCP or Chooser requests
+! Comment out this line if you want to manage X terminals with xenodm
+DisplayManager.requestPort: 0
diff --git a/configure.ac b/configure.ac
index 5529773..737cd8f 100644
--- a/configure.ac
+++ b/configure.ac
@@ -22,8 +22,8 @@ dnl Process this file with autoconf to create configure.
# Initialize Autoconf
AC_PREREQ([2.60])
-AC_INIT([opendm], [0.1],
- [https://xenocara.org], [opendm])
+AC_INIT([xenodm], [0.1],
+ [https://xenocara.org], [xenodm])
AC_USE_SYSTEM_EXTENSIONS
AC_CONFIG_SRCDIR([Makefile.am])
AC_CONFIG_MACRO_DIR([m4])
@@ -62,7 +62,7 @@ AC_CHECK_FUNCS([sigaction setproctitle setusercontext \
AC_CHECK_LIB([bsd], [arc4random_buf])
AC_CHECK_LIB([util], [login_fbtab])
-XDM_CFLAGS="$XDM_CFLAGS"
+XENODM_CFLAGS="$XENODM_CFLAGS"
GREETER_CFLAGS="$GREETER_CFLAGS"
CHOOSER_CFLAGS="$CHOOSER_CFLAGS"
@@ -119,39 +119,39 @@ fi
# Figure out where everything goes in the filesystem
-AC_ARG_WITH(xdmlibdir,
- AS_HELP_STRING([--with-xdmlibdir=<pathname>],
- [specify directory for xdm scripts and modules (default=${libdir}/X11/xdm)]),
- [XDMLIBDIR="$withval"], [XDMLIBDIR="${libdir}/X11/xdm"])
-AC_SUBST(XDMLIBDIR)
+AC_ARG_WITH(xenodmlibdir,
+ AS_HELP_STRING([--with-xenodmlibdir=<pathname>],
+ [specify directory for xenodm scripts and modules (default=${libdir}/X11/xenodm)]),
+ [XENODMLIBDIR="$withval"], [XENODMLIBDIR="${libdir}/X11/xenodm"])
+AC_SUBST(XENODMLIBDIR)
-AC_ARG_WITH(xdmconfigdir,
- AS_HELP_STRING([--with-xdmconfigdir=<pathname>],
- [specify directory for xdm config files (default is same as xdmlibdir)]),
- [XDMCONFIGDIR="$withval"], [XDMCONFIGDIR="${XDMLIBDIR}"])
-AC_SUBST(XDMCONFIGDIR)
+AC_ARG_WITH(xenodmconfigdir,
+ AS_HELP_STRING([--with-xenodmconfigdir=<pathname>],
+ [specify directory for xenodm config files (default is same as xenodmlibdir)]),
+ [XENODMCONFIGDIR="$withval"], [XENODMCONFIGDIR="${XENODMLIBDIR}"])
+AC_SUBST(XENODMCONFIGDIR)
-AC_ARG_WITH(xdmscriptdir,
- AS_HELP_STRING([--with-xdmscriptdir=<pathname>],
- [specify directory for xdm scripts (default is same as xdmlibdir)]),
- [XDMSCRIPTDIR="$withval"], [XDMSCRIPTDIR="${XDMLIBDIR}"])
-AC_SUBST(XDMSCRIPTDIR)
+AC_ARG_WITH(xenodmscriptdir,
+ AS_HELP_STRING([--with-xenodmscriptdir=<pathname>],
+ [specify directory for xenodm scripts (default is same as xenodmlibdir)]),
+ [XENODMSCRIPTDIR="$withval"], [XENODMSCRIPTDIR="${XENODMLIBDIR}"])
+AC_SUBST(XENODMSCRIPTDIR)
AC_ARG_WITH(logdir,
AS_HELP_STRING([--with-logdir=<pathname>],
- [specify directory for xdm log files (default=/var/log)]),
- [XDMLOGDIR="$withval"], [XDMLOGDIR="/var/log"])
-AC_SUBST(XDMLOGDIR)
+ [specify directory for xenodm log files (default=/var/log)]),
+ [XENODMLOGDIR="$withval"], [XENODMLOGDIR="/var/log"])
+AC_SUBST(XENODMLOGDIR)
AC_ARG_WITH(piddir,
AS_HELP_STRING([--with-piddir=<pathname>],
- [specify directory for xdm pid files (default=/var/run)]),
- [XDMPIDDIR="$withval"], [XDMPIDDIR="/var/run"])
-AC_SUBST(XDMPIDDIR)
+ [specify directory for xenodm pid files (default=/var/run)]),
+ [XENODMPIDDIR="$withval"], [XENODMPIDDIR="/var/run"])
+AC_SUBST(XENODMPIDDIR)
AC_ARG_WITH(default-vt,
AS_HELP_STRING([--with-default-vt=<vtname>],
- [specify default vt to start xdm on (default=none)]),
+ [specify default vt to start xenodm on (default=none)]),
[DEFAULTVT="$withval"], [[DEFAULTVT=""]])
AC_SUBST(DEFAULTVT)
@@ -210,7 +210,7 @@ AC_SUBST(SHELL_CMD)
# Checks for pkg-config packages
-PKG_CHECK_MODULES(XDM, xmu x11 xau)
+PKG_CHECK_MODULES(XENODM, xmu x11 xau)
PKG_CHECK_EXISTS(xinerama, [
AC_DEFINE([USE_XINERAMA], 1,
@@ -255,24 +255,24 @@ AM_CONDITIONAL(USE_XPM, test "x$USE_XPM" = "xyes")
AC_ARG_WITH(color-pixmap,
AS_HELP_STRING([--with-color-pixmap=<filename>],
[specify xpm file to use as color logo (default=xorg.xpm)]),
- [XDM_PIXMAP="$withval"], [XDM_PIXMAP="xorg.xpm"])
+ [XENODM_PIXMAP="$withval"], [XENODM_PIXMAP="xorg.xpm"])
AC_ARG_WITH(bw-pixmap,
AS_HELP_STRING([--with-bw-pixmap=<filename>],
[specify xpm file to use as black-and-white logo (default=xorg-bw.xpm)]),
- [XDM_BWPIXMAP="$withval"], [XDM_BWPIXMAP="xorg-bw.xpm"])
+ [XENODM_BWPIXMAP="$withval"], [XENODM_BWPIXMAP="xorg-bw.xpm"])
AC_ARG_WITH(pixmapdir,
AS_HELP_STRING([--with-pixmapdir=<pathname>],
- [specify directory for xpm files (default=xdmlibdir/pixmaps)]),
- [XDM_PIXMAPDIR="$withval"],
- [XDM_PIXMAPDIR='${XDMLIBDIR}/pixmaps'])
+ [specify directory for xpm files (default=xenodmlibdir/pixmaps)]),
+ [XENODM_PIXMAPDIR="$withval"],
+ [XENODM_PIXMAPDIR='${XENODMLIBDIR}/pixmaps'])
-AC_SUBST(XDM_PIXMAP)
-AC_SUBST(XDM_BWPIXMAP)
-AC_SUBST(XDM_PIXMAPDIR)
+AC_SUBST(XENODM_PIXMAP)
+AC_SUBST(XENODM_BWPIXMAP)
+AC_SUBST(XENODM_PIXMAPDIR)
# Packages used by multiple programs
-PKG_CHECK_MODULES(XDM_TOOLKIT, xaw7)
+PKG_CHECK_MODULES(XENODM_TOOLKIT, xaw7)
PKG_CHECK_MODULES(XLIB, x11)
PKG_CHECK_MODULES(AUTH, xau)
@@ -284,20 +284,20 @@ STATIC_GREETER_CFLAGS="-DGREET_USER_STATIC"
PKG_CHECK_MODULES(XDMGREET, xt >= 1.0 x11 xext)
-XDMGREET_CFLAGS="$XDMGREET_CFLAGS $XDM_TOOLKIT_CFLAGS $DMCP_CFLAGS $XLIB_CFLAGS $GREETER_CFLAGS $AUTH_CFLAGS"
-XDMGREET_LIBS="$XDMGREET_LIBS $XDM_TOOLKIT_LIBS $DMCP_LIBS $GREETER_LIBS"
+XDMGREET_CFLAGS="$XDMGREET_CFLAGS $XENODM_TOOLKIT_CFLAGS $DMCP_CFLAGS $XLIB_CFLAGS $GREETER_CFLAGS $AUTH_CFLAGS"
+XDMGREET_LIBS="$XDMGREET_LIBS $XENODM_TOOLKIT_LIBS $DMCP_LIBS $GREETER_LIBS"
#
-# XDM
+# XENODM
#
-XDM_CFLAGS="$XDM_CFLAGS $DMCP_CFLAGS $XLIB_CFLAGS $AUTH_CFLAGS $STATIC_GREETER_CFLAGS"
-XDM_LIBS="$XDM_LIBS $DMCP_LIBS"
+XENODM_CFLAGS="$XENODM_CFLAGS $DMCP_CFLAGS $XLIB_CFLAGS $AUTH_CFLAGS $STATIC_GREETER_CFLAGS"
+XENODM_LIBS="$XENODM_LIBS $DMCP_LIBS"
AC_CHECK_LIB(Xdmcp, XdmcpWrap, [xdmauth="yes"], [xdmauth="no"], [$DMCP_LIBS])
-AC_SUBST(XDM_CFLAGS)
-AC_SUBST(XDM_LIBS)
+AC_SUBST(XENODM_CFLAGS)
+AC_SUBST(XENODM_LIBS)
# Defaults for X session - should probably be configure --with-* flags
@@ -392,30 +392,30 @@ AX_DEFINE_DIR(DEF_SYSTEM_SHELL, BOURNE_SHELL,
AX_DEFINE_DIR(DEF_FAILSAFE_CLIENT, bindir/xterm,
[Define to default command to start failsafe X session])
-# -DDEF_XDM_CONFIG="$(XDMDIR)/xdm-config"
+# -DDEF_XENODM_CONFIG="$(XENODMDIR)/xenodm-config"
-AX_DEFINE_DIR(DEF_XDM_CONFIG, XDMCONFIGDIR/xdm-config,
- [Define to pathname of default xdm-config file])
+AX_DEFINE_DIR(DEF_XENODM_CONFIG, XENODMCONFIGDIR/xenodm-config,
+ [Define to pathname of default xenodm-config file])
# -DDEF_CHOOSER="$(CHOOSERPATH)"
-AX_DEFINE_DIR(DEF_CHOOSER, XDMLIBDIR/chooser,
+AX_DEFINE_DIR(DEF_CHOOSER, XENODMLIBDIR/chooser,
[Define to pathname of where chooser binary is installed])
-# -DDEF_AUTH_DIR="$(XDMDIR)"
+# -DDEF_AUTH_DIR="$(XENODMDIR)"
AC_ARG_WITH(authdir,
AS_HELP_STRING([--with-authdir=<pathname>],
- [specify directory for X auth files (default=/var/lib/xdm)]),
- [XDMXAUTHDIR="$withval"], [XDMXAUTHDIR="/var/lib/xdm"])
-AC_SUBST(XDMXAUTHDIR)
+ [specify directory for X auth files (default=/var/lib/xenodm)]),
+ [XENODMXAUTHDIR="$withval"], [XENODMXAUTHDIR="/var/lib/xenodm"])
+AC_SUBST(XENODMXAUTHDIR)
-AX_DEFINE_DIR(DEF_AUTH_DIR, XDMXAUTHDIR,
+AX_DEFINE_DIR(DEF_AUTH_DIR, XENODMXAUTHDIR,
[Define to pathname where authentication cookie files should be stored])
-# -DDEF_GREETER_LIB="$(XDMDIR)/libXdmGreet.so"
+# -DDEF_GREETER_LIB="$(XENODMDIR)/libXdmGreet.so"
-AX_DEFINE_DIR(DEF_GREETER_LIB, XDMLIBDIR/libXdmGreet.so,
+AX_DEFINE_DIR(DEF_GREETER_LIB, XENODMLIBDIR/libXdmGreet.so,
[Define to pathname where greeter shared object is installed (if used)])
PKG_CHECK_MODULES(APPDEFS, xt)
@@ -433,5 +433,5 @@ AC_CONFIG_FILES([Makefile
greeter/Makefile
include/Makefile
man/Makefile
- xdm/Makefile])
+ xenodm/Makefile])
AC_OUTPUT
diff --git a/greeter/Makefile.am b/greeter/Makefile.am
index bee262d..0cf4be1 100644
--- a/greeter/Makefile.am
+++ b/greeter/Makefile.am
@@ -1,4 +1,4 @@
-xdmlibdir = $(XDMLIBDIR)
+xenodmlibdir = $(XENODMLIBDIR)
noinst_LTLIBRARIES = libXdmGreet.la
diff --git a/man/Makefile.am b/man/Makefile.am
index 914ef67..19beb47 100644
--- a/man/Makefile.am
+++ b/man/Makefile.am
@@ -22,20 +22,20 @@
#
appmandir = $(APP_MAN_DIR)
-appman_PRE = xdm.man
+appman_PRE = xenodm.man
appman_DATA = $(appman_PRE:man=$(APP_MAN_SUFFIX))
-EXTRA_DIST = $(appman_PRE) $(xdmlman_PRE)
-CLEANFILES = $(appman_DATA) $(xdmlman_DATA) $(noinst_DATA)
+EXTRA_DIST = $(appman_PRE) $(xenodmlman_PRE)
+CLEANFILES = $(appman_DATA) $(xenodmlman_DATA) $(noinst_DATA)
SUFFIXES = .$(APP_MAN_SUFFIX) .man
# String replacements in MAN_SUBSTS now come from xorg-macros.m4 via configure
-MAN_SUBSTS += -e 's|CHOOSERPATH|$(XDMLIBDIR)/chooser|g' \
- -e 's|XDMLOGDIR|$(XDMLOGDIR)|g' \
- -e 's|XDMDIR|$(XDMCONFIGDIR)|g' \
+MAN_SUBSTS += -e 's|CHOOSERPATH|$(XENODMLIBDIR)/chooser|g' \
+ -e 's|XENODMLOGDIR|$(XENODMLOGDIR)|g' \
+ -e 's|XENODMDIR|$(XENODMCONFIGDIR)|g' \
-e 's|BINDIR|$(bindir)|g' \
- -e 's|XDMPIDDIR|$(XDMPIDDIR)|g' \
- -e 's|XDMXAUTHDIR|$(XDMXAUTHDIR)|g' \
+ -e 's|XENODMPIDDIR|$(XENODMPIDDIR)|g' \
+ -e 's|XENODMXAUTHDIR|$(XENODMXAUTHDIR)|g' \
-e 's|DEF_USER_PATH|$(DEF_USER_PATH)|g' \
-e 's|DEF_SYSTEM_PATH|$(DEF_SYSTEM_PATH)|g'
diff --git a/man/xdm.man b/man/xenodm.man
index 278000e..810d488 100644
--- a/man/xdm.man
+++ b/man/xenodm.man
@@ -23,11 +23,11 @@
.\" from The Open Group.
.\"
.\"
-.TH XDM 1 __xorgversion__
+.TH XENODM 1 __xorgversion__
.SH NAME
-xdm \- X Display Manager
+xenodm \- X Display Manager
.SH SYNOPSIS
-.B xdm
+.B xenodm
[
.B \-config
.I configuration_file
@@ -50,13 +50,13 @@ xdm \- X Display Manager
.I session_program
]
.SH DESCRIPTION
-.I Xdm
+.I Xenodm
manages a collection of X displays on the local host.
The design of
-.I xdm
+.I xenodm
was guided by the needs of X terminals as well as The Open Group standard
XDMCP, the \fIX Display Manager Control Protocol\fP.
-.I Xdm
+.I Xenodm
provides services similar to those provided by \fIinit\fP, \fIgetty\fP
and \fIlogin\fP on character terminals: prompting for login name and password,
authenticating the user, and running a ``session.''
@@ -64,7 +64,7 @@ authenticating the user, and running a ``session.''
A ``session'' is defined by the lifetime of a particular process; in the
traditional character-based terminal world, it is the user's login shell.
In the
-.I xdm
+.I xenodm
context, it is an arbitrary session manager. This is because in a windowing
environment, a user's login shell process does not necessarily have any
terminal-like interface with which to connect.
@@ -72,14 +72,14 @@ When a real session manager is not available, a window manager or terminal
emulator is typically used as the ``session manager,'' meaning that
termination of this process terminates the user's session.
.PP
-When the session is terminated, \fIxdm\fP
+When the session is terminated, \fIxenodm\fP
resets the X server and (optionally) restarts the whole process.
.PP
Because
-.I xdm
+.I xenodm
provides the first interface that users will see, it is designed to be
simple to use and easy to customize to the needs of a particular site.
-.I Xdm
+.I Xenodm
has many options, most of which have reasonable defaults. Browse through the
various sections of this manual,
picking and choosing the things you want to change.
@@ -88,30 +88,30 @@ Pay particular attention to the
section, which will describe how to
set up the style of session desired.
.SH "OVERVIEW"
-\fIxdm\fP is highly configurable, and most of its behavior can be
+\fIxenodm\fP is highly configurable, and most of its behavior can be
controlled by resource files and shell scripts. The names of these
-files themselves are resources read from the file \fIxdm-config\fP or
+files themselves are resources read from the file \fIxenodm-config\fP or
the file named by the \fB\-config\fP option.
.PP
-\fIxdm\fP can manage
+\fIxenodm\fP can manage
X servers running on the local machine and specified in
\fIXservers\fP.
.PP
-The resources of the X clients run by \fIxdm\fP outside the user's
-session, including \fIxdm\fP's own login window, can be
+The resources of the X clients run by \fIxenodm\fP outside the user's
+session, including \fIxenodm\fP's own login window, can be
affected by setting resources in the \fIXresources\fP file.
.PP
-After resetting the X server, \fIxdm\fP runs the \fIXsetup\fP script
+After resetting the X server, \fIxenodm\fP runs the \fIXsetup\fP script
to assist in setting up the screen the user sees along with the
\fIxlogin\fP widget.
.PP
-The \fIxlogin\fP widget, which \fIxdm\fP presents,
+The \fIxlogin\fP widget, which \fIxenodm\fP presents,
offers the familiar login and password prompts.
.PP
-After the user logs in, \fIxdm\fP runs the \fIXstartup\fP script as
+After the user logs in, \fIxenodm\fP runs the \fIXstartup\fP script as
root.
.PP
-Then \fIxdm\fP runs the \fIXsession\fP script as the user. This
+Then \fIxenodm\fP runs the \fIXsession\fP script as the user. This
system session file may do some additional startup and typically runs
the \fI.xsession\fP script in the user's home directory.
When the \fIXsession\fP script exits, the session is over.
@@ -119,15 +119,15 @@ When the \fIXsession\fP script exits, the session is over.
At the end of the session, the \fIXreset\fP script is run to clean up,
the X server is reset, and the cycle starts over.
.PP
-The file \fI XDMLOGDIR/xdm.log\fP will contain error
+The file \fI XENODMLOGDIR/xenodm.log\fP will contain error
messages from
-.I xdm
+.I xenodm
and anything output to stderr by \fIXsetup, Xstartup, Xsession\fP
or \fIXreset\fP.
When you have trouble getting
-.I xdm
+.I xenodm
working, check this file to see if
-.I xdm
+.I xenodm
has any clues to the trouble.
.SH OPTIONS
.PP
@@ -137,34 +137,34 @@ as resources.
.IP "\fB\-config\fP \fIconfiguration_file\fP"
Names the configuration file, which specifies resources to control
the behavior of
-.I xdm.
-.I XDMDIR/xdm-config
+.I xenodm.
+.I XENODMDIR/xenodm-config
is the default.
See the section \fBConfiguration File\fP.
.IP "\fB\-nodaemon\fP"
Specifies ``false'' as the value for the \fBDisplayManager.daemonMode\fP
resource.
This suppresses the normal daemon behavior, which is for
-.I xdm
+.I xenodm
to close all file descriptors, disassociate itself from
the controlling terminal, and put
itself in the background when it first starts up.
.IP "\fB\-debug\fP \fIdebug_level\fP"
Specifies the numeric value for the \fBDisplayManager.debugLevel\fP
resource. A non-zero value causes
-.I xdm
+.I xenodm
to print lots of debugging statements to the terminal; it also disables the
\fBDisplayManager.daemonMode\fP resource, forcing
-.I xdm
+.I xenodm
to run synchronously. To interpret these debugging messages, a copy
of the source code for
-.I xdm
+.I xenodm
is almost a necessity. No attempt has been
made to rationalize or standardize the output.
.IP "\fB\-error\fP \fIerror_log_file\fP"
Specifies the value for the \fBDisplayManager.errorLogFile\fP resource.
This file contains errors from
-.I xdm
+.I xenodm
as well as anything written to stderr by the various scripts and programs
run during the progress of the session.
.IP "\fB\-resources\fP \fIresource_file\fP"
@@ -186,11 +186,11 @@ Allows an arbitrary resource to be specified, as in most
X Toolkit applications.
.SH RESOURCES
At many stages the actions of
-.I xdm
+.I xenodm
can be controlled through the use of its configuration file, which is in the
X resource format.
Some resources modify the behavior of
-.I xdm
+.I xenodm
on all displays,
while others modify its behavior on a single display. Where actions relate
to a specific display,
@@ -203,7 +203,7 @@ For local displays, the resource name and class are as read from the
Because the resource
manager uses colons to separate the name of the resource from its value and
dots to separate resource name parts,
-.I xdm
+.I xenodm
substitutes underscores for both dots and colons when generating the resource
name.
For example, \fBDisplayManager.expo_x_org_0.startup\fP is the name of the
@@ -229,11 +229,11 @@ reams of
debugging information will be printed. It also disables daemon mode, which
would redirect the information into the bit-bucket, and
allows non-root users to run
-.I xdm,
+.I xenodm,
which would normally not be useful.
.IP "\fBDisplayManager.daemonMode\fP"
Normally,
-.I xdm
+.I xenodm
attempts to make itself into a daemon process unassociated with any terminal.
This is
accomplished by forking and leaving the parent process to exit, then closing
@@ -242,18 +242,18 @@ environments this is not desired (in particular, when debugging). Setting
this resource to ``false'' will disable this feature.
.IP "\fBDisplayManager.authDir\fP"
This names a directory under which
-.I xdm
+.I xenodm
stores authorization files while initializing the session. The
-default value is \fI XDMXAUTHDIR.\fP
+default value is \fI XENODMXAUTHDIR.\fP
Can be overridden for specific displays by
DisplayManager.\fIDISPLAY\fP.authFile.
.IP \fBDisplayManager.autoRescan\fP
This boolean controls whether
-.I xdm
+.I xenodm
rescans the configuration, servers, access control and authentication keys
files after a session terminates and the files have changed. By default it
is ``true.'' You can force
-.I xdm
+.I xenodm
to reread these files by sending a SIGHUP to the main process.
.IP \fBDisplayManager.exportList\fP
A list of additional environment variables, separated by white space,
@@ -276,11 +276,11 @@ section
which describes the various
resources that are appropriate to place in this file.
There is no default value for this resource, but
-\fI XDMDIR/Xresources\fP
+\fI XENODMDIR/Xresources\fP
is the conventional name.
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.xrdb\fP"
Specifies the program used to load the resources. By default,
-.I xdm
+.I xenodm
uses \fI BINDIR/xrdb\fP.
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.cpp\fP"
This specifies the name of the C preprocessor which is used by \fIxrdb\fP.
@@ -315,7 +315,7 @@ See the section
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.startAttempts\fP"
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.reservAttempts\fP"
These numeric resources control the behavior of
-.I xdm
+.I xenodm
when attempting to open intransigent servers. \fBopenDelay\fP is
the length of the
pause in seconds between successive attempts, \fBopenRepeat\fP is the
@@ -327,7 +327,7 @@ system call) and \fBstartAttempts\fP is the number of times this
entire process is done before giving up on the server.
After \fBopenRepeat\fP attempts have been made, or
if \fBopenTimeout\fP seconds elapse in any particular attempt,
-.I xdm
+.I xenodm
terminates and restarts the server, attempting to connect again.
This process is repeated \fBstartAttempts\fP times, at which point
the display is declared dead and disabled. Although
@@ -341,7 +341,7 @@ The default values are
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.pingInterval\fP"
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.pingTimeout\fP"
To discover when remote displays disappear,
-.I xdm
+.I xenodm
occasionally pings them, using an X connection and \fIXSync\fP
calls. \fBpingInterval\fP specifies the time (in minutes) between each
ping attempt, \fBpingTimeout\fP specifies the maximum amount of time (in
@@ -351,7 +351,7 @@ default, both are set to 5 minutes. If you frequently use X terminals which
can become isolated from the managing host, you may wish to increase this
value. The only worry is that sessions will continue to exist after the
terminal has been accidentally disabled.
-.I xdm
+.I xenodm
will not ping local displays. Although it would seem harmless, it is
unpleasant when the workstation session is terminated as a result of the
server hanging for NFS service and not responding to the ping.
@@ -361,26 +361,26 @@ when a session terminates (instead of resetting it). This option can be
used when the server tends to grow without bound over time, in order to limit
the amount of time the server is run. The default value is ``false.''
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.userPath\fP"
-.I Xdm
+.I Xenodm
sets the PATH environment variable for the session to this value. It should
be a colon separated list of directories; see
.IR sh (__appmansuffix__)
for a full description.
The default value is ``DEF_USER_PATH''.
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.systemPath\fP"
-.I Xdm
+.I Xenodm
sets the PATH environment variable for the startup and reset scripts to the
value of this resource. The default for this resource is ``DEF_SYSTEM_PATH''.
Note the absence of ``.'' from this entry. This is a good practice to
follow for root; it avoids many common Trojan Horse system penetration
schemes.
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.systemShell\fP"
-.I Xdm
+.I Xenodm
sets the SHELL environment variable for the startup and reset scripts to the
value of this resource. It is \fI/bin/sh\fP by default.
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.failsafeClient\fP"
If the default session fails to execute,
-.I xdm
+.I xenodm
will fall back to this program. This program is executed with no
arguments, but executes using the same environment variables as
the session would have had (see the section \fBSession Program\fP).
@@ -388,7 +388,7 @@ By default, \fI BINDIR/xterm\fP is used.
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.grabServer\fP"
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.grabTimeout\fP"
To improve security,
-.I xdm
+.I xenodm
grabs the server and keyboard while reading the login name and password.
The
\fBgrabServer\fP resource specifies if the server should be held for the
@@ -396,18 +396,18 @@ duration of the name/password reading. When ``false,'' the server is ungrabbed
after the keyboard grab succeeds, otherwise the server is grabbed until just
before the session begins. The default is ``false.''
The \fBgrabTimeout\fP resource specifies the maximum time
-.I xdm
+.I xenodm
will wait for the grab to succeed. The grab may fail if some other
client has the server grabbed, or possibly if the network latencies
are very high. This resource has a default value of 3 seconds; you
should be cautious when raising it, as a user can be spoofed by a
look-alike window on the display. If the grab fails,
-.I xdm
+.I xenodm
kills and restarts the server (if possible) and the session.
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.authorize\fP"
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.authName\fP"
\fBauthorize\fP is a boolean resource which controls whether
-.I xdm
+.I xenodm
generates and uses authorization for the local server connections. If
authorization is used, \fBauthName\fP is a list
of authorization mechanisms to use, separated by white space.
@@ -420,7 +420,7 @@ is ``true,'' \fBauthName\fP is ``MIT-MAGIC-COOKIE-1,'' or, if
XDM-AUTHORIZATION-1 is available, ``XDM-AUTHORIZATION-1\0MIT-MAGIC-COOKIE-1.''
.IP \fBDisplayManager.\fP\fIDISPLAY\fP\fB.authFile\fP
This file is used to communicate the authorization data from
-.I xdm
+.I xenodm
to the server, using the \fB\-auth\fP server command line option.
It should be
kept in a directory which is not world-writable as it could easily be
@@ -433,50 +433,50 @@ in the login window.
See the section \fBAuthentication Widget.\fP
The default is ``true.''
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.resetSignal\fP"
-The number of the signal \fIxdm\fP sends to reset the server.
+The number of the signal \fIxenodm\fP sends to reset the server.
See the section \fBControlling the Server.\fP
The default is 1 (SIGHUP).
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.termSignal\fP"
-The number of the signal \fIxdm\fP sends to terminate the server.
+The number of the signal \fIxenodm\fP sends to terminate the server.
See the section \fBControlling the Server.\fP
The default is 15 (SIGTERM).
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.resetForAuth\fP"
The original implementation of authorization in the sample server reread the
authorization file at server reset time, instead of when checking the
initial connection. As
-.I xdm
+.I xenodm
generates the authorization information just before connecting to the
display, an old server would not get up-to-date authorization information.
This resource causes
-.I xdm
+.I xenodm
to send SIGHUP to the server after setting up the file, causing an
additional server reset to occur, during which time the new authorization
information will be read.
The default is ``false,'' which will work for all MIT servers.
.IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.userAuthDir\fP"
When
-.I xdm
+.I xenodm
is unable to write to the usual user authorization file ($HOME/.Xauthority),
it creates a unique file name in this directory and points the environment
variable XAUTHORITY at the created file. It uses \fI/tmp\fP by default.
.SH "CONFIGURATION FILE"
First, the
-.I xdm
+.I xenodm
configuration file should be set up.
-Make a directory (usually \fI XDMDIR\fP) to contain all
+Make a directory (usually \fI XENODMDIR\fP) to contain all
of the relevant files.
.LP
Here is a reasonable configuration file, which could be
-named \fIxdm-config\fP:
+named \fIxenodm-config\fP:
.nf
.ta .5i 4i
- DisplayManager.servers: XDMDIR/Xservers
- DisplayManager.errorLogFile: XDMLOGDIR/xdm.log
- DisplayManager*resources: XDMDIR/Xresources
- DisplayManager*startup: XDMDIR/Xstartup
- DisplayManager*session: XDMDIR/Xsession
+ DisplayManager.servers: XENODMDIR/Xservers
+ DisplayManager.errorLogFile: XENODMLOGDIR/xenodm.log
+ DisplayManager*resources: XENODMDIR/Xresources
+ DisplayManager*startup: XENODMDIR/Xstartup
+ DisplayManager*session: XENODMDIR/Xsession
DisplayManager._0.authorize: true
DisplayManager*authorize: false
@@ -497,7 +497,7 @@ Each specification
indicates a display which should constantly be managed and which is
not using XDMCP.
This method is used typically for local servers only. If the resource
-or the file named by the resource is empty, \fIxdm\fP will exit.
+or the file named by the resource is empty, \fIxenodm\fP will exit.
.PP
Each specification consists of at least three parts: a display
name, a display class, a display type, and (for local servers) a command
@@ -512,8 +512,8 @@ The display types are:
.ta 1i
.nf
-local local display: \fIxdm\fP must run the server
-foreign remote display: \fIxdm\fP opens an X connection to a running server
+local local display: \fIxenodm\fP must run the server
+foreign remote display: \fIxenodm\fP opens an X connection to a running server
.fi
.PP
@@ -528,8 +528,8 @@ display-specific resources, as the class of the resource. This is
useful if you have a large collection of similar displays (such as a corral of
X terminals) and would like to set resources for groups of them.
.PP
-When \fIxdm\fP starts a session, it sets up authorization data for the
-server. For local servers, \fIxdm\fP passes
+When \fIxenodm\fP starts a session, it sets up authorization data for the
+server. For local servers, \fIxenodm\fP passes
``\fB\-auth\fP \fIfilename\fP'' on the server's command line to point
it at its authorization data.
.SH RESOURCES FILE
@@ -583,7 +583,7 @@ the following environment variables are passed:
XAUTHORITY may be set to an authority file
.fi
.PP
-Note that since \fIxdm\fP grabs the keyboard, any other windows will not be
+Note that since \fIxenodm\fP grabs the keyboard, any other windows will not be
able to receive keyboard input. They will be able to interact with
the mouse, however; beware of potential security holes here.
If \fBDisplayManager.\fP\fIDISPLAY\fP\fB.grabServer\fP is set,
@@ -598,7 +598,7 @@ Here is a sample \fIXsetup\fP script:
\& #!/bin/sh
\& # Xsetup_0 \- setup script for one workstation
- xcmsdb < XDMDIR/monitors/alex.0
+ xcmsdb < XENODMDIR/monitors/alex.0
xconsole\0\-geometry\0480x130\-0\-0\0\-notify\0\-verbose\0\-exitOnFail &
.fi
@@ -617,7 +617,7 @@ for the client hostname in the login message, or C pre-processor #ifdef
statements to produce different displays depending on color depth or other
variables.
.PP
-.I Xdm
+.I Xenodm
can be compiled with support for the
.IR Xft (__libmansuffix__)
library for font rendering. If this support is present, font faces are
@@ -786,7 +786,7 @@ Erases the entire text.
.IP "finish-field"
If the cursor is in the name field, proceeds to the password field; if the
cursor is in the password field, checks the current name/password pair. If
-the name/password pair is valid, \fIxdm\fP
+the name/password pair is valid, \fIxenodm\fP
starts the session. Otherwise the failure message is displayed and
the user is prompted again.
.IP "abort-session"
@@ -794,11 +794,11 @@ Terminates and restarts the server.
.IP "abort-display"
Terminates the server, disabling it. This action
is not accessible in the default configuration.
-There are various reasons to stop \fIxdm\fP on a system console, such as
+There are various reasons to stop \fIxenodm\fP on a system console, such as
when shutting the system down, when using \fIxdmshell\fP,
to start another type of server, or to generally access the console.
-Sending \fIxdm\fP a SIGHUP will restart the display. See the section
-\fBControlling XDM\fP.
+Sending \fIxenodm\fP a SIGHUP will restart the display. See the section
+\fBControlling XENODM\fP.
.IP "restart-session"
Resets the X server and starts a new session. This can be used when
the resources have been changed and you want to test them or when
@@ -811,14 +811,14 @@ See the section \fBSession Program\fP.
.IP "allow-all-access"
Disables access control in the server. This can be used when
the .Xauthority file cannot be created by
-.I xdm.
+.I xenodm.
Be very careful using this;
it might be better to disconnect the machine from the network
before doing this.
.PP
On some systems (OpenBSD) the user's shell must be listed in
.I /etc/shells
-to allow login through xdm. The normal password and account expiration
+to allow login through xenodm. The normal password and account expiration
dates are enforced too.
.SH "STARTUP PROGRAM"
.PP
@@ -850,10 +850,10 @@ the following environment variables are passed:
.fi
.PP
No arguments are passed to the script.
-.I Xdm
+.I Xenodm
waits until this script exits before starting the user session. If the
exit value of this script is non-zero,
-.I xdm
+.I xenodm
discontinues the session and starts another authentication
cycle.
.PP
@@ -877,8 +877,8 @@ Here is a sample \fIXstartup\fP script:
xmessage\0\-file /etc/nologin\0\-timeout 30\0\-center
exit 1
fi
- sessreg\0\-a\0\-l $DISPLAY\0\-x XDMDIR/Xservers $LOGNAME
- XDMDIR/GiveConsole
+ sessreg\0\-a\0\-l $DISPLAY\0\-x XENODMDIR/Xservers $LOGNAME
+ XENODMDIR/GiveConsole
exit 0
.fi
.SH "SESSION PROGRAM"
@@ -991,12 +991,12 @@ A sample \fIXreset\fP script:
\& #
\& # This program is run as root after the session ends
\& #
- sessreg\0\-d\0\-l $DISPLAY\0\-x XDMDIR/Xservers $LOGNAME
- XDMDIR/TakeConsole
+ sessreg\0\-d\0\-l $DISPLAY\0\-x XENODMDIR/Xservers $LOGNAME
+ XENODMDIR/TakeConsole
exit 0
.fi
.SH "CONTROLLING THE SERVER"
-.I Xdm
+.I Xenodm
controls local servers using POSIX signals. SIGHUP is expected to reset the
server, closing all client connections and performing other cleanup
duties. SIGTERM is expected to terminate the server.
@@ -1005,41 +1005,41 @@ the resources \fBDisplayManager.\fP\fIDISPLAY\fP\fB.resetSignal\fP and
\fBDisplayManager.\fP\fIDISPLAY\fP\fB.termSignal\fP can specify alternate signals.
.PP
To control remote terminals not using XDMCP,
-.I xdm
+.I xenodm
searches the window hierarchy on the display and uses the protocol request
KillClient in an attempt to clean up the terminal for the next session. This
may not actually kill all of the clients, as only those which have created
windows will be noticed. XDMCP provides a more sure mechanism; when
-.I xdm
+.I xenodm
closes its initial connection, the session is over and the terminal is
required to close all other connections.
-.SH "CONTROLLING XDM"
+.SH "CONTROLLING XENODM"
.PP
-.I Xdm
+.I Xenodm
responds to two signals: SIGHUP and SIGTERM. When sent a SIGHUP,
-.I xdm
+.I xenodm
rereads the configuration file, the access control file, and the servers
file. For the servers file, it notices if entries have been added or
removed. If a new entry has been added,
-.I xdm
+.I xenodm
starts a session on the associated display. Entries which have been removed
are disabled immediately, meaning that any session in progress will be
terminated without notice and no new session will be started.
.PP
When sent a SIGTERM,
-.I xdm
+.I xenodm
terminates all sessions in progress and exits. This can be used when
shutting down the system.
.PP
-.I Xdm
+.I Xenodm
attempts to mark its various sub-processes for
.IR ps (__appmansuffix__)
by editing the
command line argument list in place. Because
-.I xdm
+.I xenodm
can't allocate additional
space for this task, it is useful to start
-.I xdm
+.I xenodm
with a reasonably long
command line (using the full path name should be enough).
Each process which is
@@ -1050,21 +1050,21 @@ To add an additional local display, add a line for it to the
\fIXservers\fP file.
(See the section \fBLocal Server Specification\fP.)
.PP
-Examine the display-specific resources in \fIxdm-config\fP
+Examine the display-specific resources in \fIxenodm-config\fP
(e.g., \fBDisplayManager._0.authorize\fP)
and consider which of them should be copied for the new display.
-The default \fIxdm-config\fP has all the appropriate lines for
+The default \fIxenodm-config\fP has all the appropriate lines for
displays \fB:0\fP and \fB:1\fP.
.SH "OTHER POSSIBILITIES"
.PP
-You can use \fIxdm\fP
+You can use \fIxenodm\fP
to run a single session at a time, using the 4.3 \fIinit\fP
options or other suitable daemon by specifying the server on the command
line:
.nf
.ta .5i
- xdm \-server \(lq:0 SUN-3/60CG4 local BINDIR/X :0\(rq
+ xenodm \-server \(lq:0 SUN-3/60CG4 local BINDIR/X :0\(rq
.fi
.PP
@@ -1081,25 +1081,25 @@ except the \fIXservers\fP file would look like
.fi
.PP
This directs
-.I xdm
+.I xenodm
to manage sessions on all three of these terminals. See the section
-\fBControlling Xdm\fP for a description of using signals to enable
+\fBControlling Xenodm\fP for a description of using signals to enable
and disable these terminals in a manner reminiscent of
.IR init (__adminmansuffix__).
.SH LIMITATIONS
One thing that
-.I xdm
+.I xenodm
isn't very good at doing is coexisting with other window systems. To use
multiple window systems on the same hardware, you'll probably be more
interested in
.I xinit.
.SH FILES
.TP 20
-.I XDMDIR/xdm-config
+.I XENODMDIR/xenodm-config
the default configuration file
.TP 20
.I $HOME/.Xauthority
-user authorization file where \fIxdm\fP stores keys for clients to read
+user authorization file where \fIxenodm\fP stores keys for clients to read
.TP 20
.I CHOOSERPATH
the default chooser
@@ -1113,7 +1113,7 @@ the default server
.I BINDIR/xterm
the default session program and failsafe client
.TP 20
-.I XDMXAUTHDIR/A<display>\-<suffix>
+.I XENODMXAUTHDIR/A<display>\-<suffix>
the default place for authorization files
.TP 20
.I /tmp/K5C<display>
@@ -1127,7 +1127,6 @@ Kerberos credentials cache
.IR sessreg (__appmansuffix__),
.IR Xserver (__appmansuffix__),
.\" .IR chooser (__appmansuffix__), \" except that there isn't a manual for it yet
-.IR xdmshell (__appmansuffix__),
.IR fonts.conf (__filemansuffix__).
.br
.I "X Display Manager Control Protocol"
diff --git a/xdm/Makefile.am b/xenodm/Makefile.am
index ccfea71..ea41418 100644
--- a/xdm/Makefile.am
+++ b/xenodm/Makefile.am
@@ -19,16 +19,16 @@
# TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
# PERFORMANCE OF THIS SOFTWARE.
-bin_PROGRAMS = xdm
+bin_PROGRAMS = xenodm
AM_CPPFLAGS = -I$(top_srcdir)/include
-AM_CFLAGS = $(CWARNFLAGS) $(XDM_CFLAGS)
+AM_CFLAGS = $(CWARNFLAGS) $(XENODM_CFLAGS)
-AM_LDFLAGS = $(XDM_LIBS)
+AM_LDFLAGS = $(XENODM_LIBS)
LDADD = ../greeter/libXdmGreet.la
-xdm_SOURCES = \
+xenodm_SOURCES = \
auth.c \
dm.c \
dpylist.c \
@@ -47,6 +47,6 @@ ALL_LINT_FLAGS=$(LINT_FLAGS) $(DEFS) $(DEFAULT_INCLUDES) \
$(AM_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS)
lint:
- $(LINT) $(ALL_LINT_FLAGS) $(xdm_SOURCES) $(XDM_LIBS)
+ $(LINT) $(ALL_LINT_FLAGS) $(xenodm_SOURCES) $(XENODM_LIBS)
endif LINT
diff --git a/xdm/auth.c b/xenodm/auth.c
index 7c9697c..7c9697c 100644
--- a/xdm/auth.c
+++ b/xenodm/auth.c
diff --git a/xdm/dpylist.c b/xenodm/dpylist.c
index c430670..c430670 100644
--- a/xdm/dpylist.c
+++ b/xenodm/dpylist.c
diff --git a/xdm/error.c b/xenodm/error.c
index 59ae069..59ae069 100644
--- a/xdm/error.c
+++ b/xenodm/error.c
diff --git a/xdm/file.c b/xenodm/file.c
index 194e8df..194e8df 100644
--- a/xdm/file.c
+++ b/xenodm/file.c
diff --git a/xdm/mitauth.c b/xenodm/mitauth.c
index 51bf4cb..51bf4cb 100644
--- a/xdm/mitauth.c
+++ b/xenodm/mitauth.c
diff --git a/xdm/netaddr.c b/xenodm/netaddr.c
index ad2bff0..ad2bff0 100644
--- a/xdm/netaddr.c
+++ b/xenodm/netaddr.c
diff --git a/xdm/reset.c b/xenodm/reset.c
index aff01ea..aff01ea 100644
--- a/xdm/reset.c
+++ b/xenodm/reset.c
diff --git a/xdm/resource.c b/xenodm/resource.c
index 398bcd0..5c84ffc 100644
--- a/xdm/resource.c
+++ b/xenodm/resource.c
@@ -85,17 +85,17 @@ int choiceTimeout; /* chooser choice timeout */
#ifndef DEF_FAILSAFE_CLIENT
# define DEF_FAILSAFE_CLIENT "/usr/bin/X11/xterm"
#endif
-#ifndef DEF_XDM_CONFIG
-# define DEF_XDM_CONFIG "/usr/lib/X11/xdm/xdm-config"
+#ifndef DEF_XENODM_CONFIG
+# define DEF_XENODM_CONFIG "/usr/lib/X11/xenodm/xenodm-config"
#endif
#ifndef DEF_CHOOSER
-# define DEF_CHOOSER "/usr/lib/X11/xdm/chooser"
+# define DEF_CHOOSER "/usr/lib/X11/xenodm/chooser"
#endif
#ifndef DEF_AUTH_NAME
# define DEF_AUTH_NAME "MIT-MAGIC-COOKIE-1"
#endif
#ifndef DEF_AUTH_DIR
-# define DEF_AUTH_DIR "/usr/lib/X11/xdm"
+# define DEF_AUTH_DIR "/usr/lib/X11/xenodm"
#endif
#ifndef DEF_USER_AUTH_DIR
# define DEF_USER_AUTH_DIR "/tmp"
@@ -107,7 +107,7 @@ int choiceTimeout; /* chooser choice timeout */
# define DEF_ACCESS_FILE ""
#endif
#ifndef DEF_GREETER_LIB
-# define DEF_GREETER_LIB "/usr/lib/X11/xdm/libXdmGreet.so"
+# define DEF_GREETER_LIB "/usr/lib/X11/xenodm/libXdmGreet.so"
#endif
struct dmResources {
@@ -356,7 +356,7 @@ ReinitResources (void)
sizeof (configTable) / sizeof (configTable[0]),
"DisplayManager", &argc, argv);
GetResource ("DisplayManager.configFile", "DisplayManager.ConfigFile",
- DM_STRING, &config, DEF_XDM_CONFIG);
+ DM_STRING, &config, DEF_XENODM_CONFIG);
newDB = XrmGetFileDatabase ( config );
if (newDB)
{
diff --git a/xdm/server.c b/xenodm/server.c
index c7bef40..c7bef40 100644
--- a/xdm/server.c
+++ b/xenodm/server.c
diff --git a/xdm/session.c b/xenodm/session.c
index 19fca9c..29a9dd6 100644
--- a/xdm/session.c
+++ b/xenodm/session.c
@@ -226,6 +226,7 @@ ManageSession (struct display *d)
/*
* run system-wide reset file
*/
+ login_fbtab(d->windowPath, 0, 0);
Debug ("Source reset program %s\n", d->reset);
source (verify.systemEnviron, d->reset);
SessionExit (d, OBEYSESS_DISPLAY, TRUE);
diff --git a/xdm/util.c b/xenodm/util.c
index be5081a..be5081a 100644
--- a/xdm/util.c
+++ b/xenodm/util.c
diff --git a/xdm/dm.c b/xenodm/dm.c
index 5a4c6f6..18d1227 100644
--- a/xdm/dm.c
+++ b/xenodm/dm.c
@@ -64,7 +64,7 @@ int nofork_session = 0;
static void ChildNotify (int n);
-static pid_t parent_pid = -1; /* PID of parent xdm process */
+static pid_t parent_pid = -1; /* PID of parent xenodm process */
int
main (int argc, char **argv)
@@ -268,7 +268,7 @@ StopAll (int n)
*
* See defect XWSog08655 for more information.
*/
- Debug ("Child xdm caught SIGTERM before it removed that signal.\n");
+ Debug ("Child xenodm caught SIGTERM before it removed that signal.\n");
(void) signal (n, SIG_DFL);
kill (getpid(), SIGTERM);
errno = olderrno;
@@ -611,7 +611,7 @@ StartDisplay (struct display *d)
CleanUpChild ();
(void) signal (SIGPIPE, SIG_IGN);
}
- openlog("xdm", LOG_PID, LOG_AUTHPRIV);
+ openlog("xenodm", LOG_PID, LOG_AUTHPRIV);
LoadSessionResources (d);
SetAuthorization (d);
if (!WaitForServer (d))